@@ -5,7 +5,7 @@
 
 from traitlets import Bool
 
-from ..utils.base import NbConvertBase
+from nbconvert.utils.base import NbConvertBase
 
 
 class Preprocessor(NbConvertBase):
@@ -85,6 +85,6 @@ class Preprocessor(NbConvertBase):
         index : int
             Index of the cell being processed
         """
-
-        raise NotImplementedError("should be implemented by subclass")
+        msg = "should be implemented by subclass"
+        raise NotImplementedError(msg)
         return cell, resources
